"""Sphinx configuration file."""
import os
import sys

import django
from pkg_resources import get_distribution

os.environ.setdefault("DJANGO_SETTINGS_MODULE", "tests.testapp.settings")
sys.path.insert(0, os.path.abspath(".."))
django.setup()

project = "Django Mail Auth"
copyright = "2019, Johannes Hoppe"
release = get_distribution("django-mail-auth").version
version = ".".join(release.split(".")[:2])

master_doc = "index"

extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.napoleon",
    "sphinx.ext.intersphinx",
    "sphinx.ext.doctest",
]

intersphinx_mapping = {
    "python": ("https://docs.python.org/3", None),
    "django": (
        "https://docs.djangoproject.com/en/stable/",
        "https://docs.djangoproject.com/en/stable/_objects/",
    ),
}


autodoc_default_options = {
    "show-inheritance": True,
}



from django.contrib.auth.views import LogoutView
from django.urls import path, re_path

from mailauth import views

app_name = "mailauth"

urlpatterns = [
    path("login/", views.LoginView.as_view(), name="login"),
    path("login/success/", views.LoginRequestedView.as_view(), name="login-success"),
    re_path("login/(?P<token>.*)$", views.LoginTokenView.as_view(), name="login-token"),
    path("logout/", LogoutView.as_view(), name="logout"),
]



from django.contrib import admin
from django.contrib.auth.models import Group, Permission

from . import models


@admin.register(models.EmailUser)
class EmailUserAdmin(admin.ModelAdmin):
    app_label = "asdf"
    list_display = ("email", "first_name", "last_name", "is_staff")
    list_filter = ("is_staff", "is_superuser", "is_active", "groups")
    search_fields = ("first_name", "last_name", "email")
    ordering = ("email",)
    filter_horizontal = (
        "groups",
        "user_permissions",
    )

    fieldsets = (
        (None, {"fields": (("email", "is_active"), ("first_name", "last_name"))}),
        (
            Group._meta.verbose_name_plural,
            {
                "fields": ("groups",),
            },
        ),
        (
            Permission._meta.verbose_name_plural,
            {
                "classes": ("collapse",),
                "fields": (("is_staff", "is_superuser"), "user_permissions"),
            },
        ),
    )



from django.contrib.auth import REDIRECT_FIELD_NAME
from django.urls import reverse
from django.utils.translation import gettext_lazy as _

from mailauth.views import LoginView


class AdminLoginView(LoginView):
    template_name = "mailauth_admin/login.html"
    site = None

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        context.update(
            {
                **self.site.each_context(self.request),
                "title": _("Log in"),
                "app_path": self.request.get_full_path(),
                "username": self.request.user.get_username(),
            }
        )
        if (
            REDIRECT_FIELD_NAME not in self.request.GET
            and REDIRECT_FIELD_NAME not in self.request.POST
        ):
            context[REDIRECT_FIELD_NAME] = reverse(
                "admin:index", current_app=self.site.name
            )
        return context



from django.db import migrations

try:
    from django.contrib.postgres.fields import CIEmailField
except ImportError:
    CIEmailField = None
else:
    from django.contrib.postgres.operations import CITextExtension


def _operations():
    if CIEmailField:
        yield CITextExtension()
        yield migrations.AlterField(
            model_name="emailuser",
            name="email",
            field=CIEmailField(
                db_index=True, max_length=254, unique=True, verbose_name="email address"
            ),
        )
    else:
        yield migrations.RunSQL(
            sql=(
                "CREATE UNIQUE INDEX mailauth_user_emailuser_email_upper_idx"
                ' ON mailauth_user_emailuser (UPPER("email"));',
            ),
            reverse_sql=("DROP INDEX mailauth_user_emailuser_email_upper_idx;",),
        )


class Migration(migrations.Migration):
    dependencies = [
        ("mailauth_user", "0002_emailuser_session_salt"),
    ]

    operations = list(_operations())



# Generated by Django 2.2.1 on 2019-05-27 10:39

from django.db import migrations, models

import mailauth


class Migration(migrations.Migration):

    dependencies = [
        ("mailauth_user", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="emailuser",
            name="session_salt",
            field=models.CharField(
                default=mailauth.contrib.user.models._get_session_salt,
                editable=False,
                max_length=12,
            ),
        ),
    ]
